@@ -1,6 +1,6 @@
 package Quantum::Superpositions::Lazy::Role::Operation;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use v5.24;
 use warnings;
@@ -20,9 +20,8 @@ has "sign" => (
 sub _clear_parameters
 {
 	my ($self, $param_num, @parameters) = @_;
-	@parameters = grep defined, @parameters;
 
-	my ($params_min, $params_max) = ref $param_num eq ref []
+	my ($params_min, $params_max) = ref $param_num eq 'ARRAY'
 		? $param_num->@*
 		: ($param_num, undef)
 		;
@@ -32,8 +31,7 @@ sub _clear_parameters
 
 	croak "too many parameters to " . $self->sign
 		if defined $params_max && @parameters > $params_max;
-
-	return @parameters;
 }
 
 1;
+
